Learn R Programming

riemstats (version 0.2.0)

pillais_trace: Compute Pillai's Trace Statistic

Description

Calculates Pillai's trace statistic for a given super_sample object. This function ensures that the within-group and total covariance matrices are computed, then computes the sum of the eigenvalues of the matrix (Total - Within) %*% solve(Total).

Usage

pillais_trace(super_sample)

Value

A numeric value representing Pillai's trace statistic.

Arguments

super_sample

An object of class CSuperSample

Details

Pillai's trace is a test statistic for the ANOVA test decribed in (to appear).